@@ -320,7 +320,7 @@ def output_alignments(narrow_ga, ga_windows, reference_genome, target_sequence,
           # 'Position.Pvalue', 'Narrow.Pvalue', 'Position.Control.Pvalue', 'Narrow.Control.Pvalue','control_position_counts','control_window_counts',  # 30:33
           # sep='\t', file=o1)
     # Yichao Redefine output
-    print('Chromosome', 'Start', 'End', 'Genomic Coordinate', 'Nuclease_Read_Count', 'Strand',  # 0:5 bed6 format
+    print('#Chromosome', 'Start', 'End', 'Genomic Coordinate', 'Nuclease_Read_Count', 'Strand',  # 0:5 bed6 format
           'Control_Read_Count','Site_Sequence','Site_Substitution_Number','Site_Sequence_Gaps_Allowed', # contron window count, # 10:11, 15
           'File_Name', 'Cell', 'Target_site', 'Full_Name', 'Target_Sequence', 'Realigned_Target_Sequence',  # 24:29
           sep='\t', file=o1)
@@ -421,11 +421,16 @@ def regexFromSequence(seq, lookahead=True, indels=1, errors=7):
                             'R': '[AGR]',
                             'W': '[ATW]',
                             'S': '[CGS]',
+                            'K': '[GTK]',
+                            'M': '[ACM]',
+                            'H': '[ACTH]',
+                            'B': '[CGTB]',
+                            'D': '[AGTD]',
+                            'V': '[ACGV]',
                             'A': 'A',
                             'T': 'T',
                             'C': 'C',
                             'G': 'G'}
-
     pattern = ''
 
     for c in seq:
@@ -441,7 +446,7 @@ def regexFromSequence(seq, lookahead=True, indels=1, errors=7):
 """
 Allow for '-' in our search, but do not allow insertions or deletions. 
 """
-def extendedPattern(seq, errors):
+def extendedPattern(seq, errors): # 0921, Seems this function is not used, Yichao
     IUPAC_notation_regex_extended = {'N': '[ATCGN]','-': '[ATCGN]','Y': '[CTY]','R': '[AGR]','W': '[ATW]','S': '[CGS]','A': 'A','T': 'T','C': 'C','G': 'G'}
     realign_pattern = ''
     for c in seq:
@@ -673,21 +678,26 @@ def compare(ref, bam, control, targetsite, search_radius, windowsize, mapq_thres
 
         # Empirical cdf
         #print(bg_position, bg_narrow)
-        ecdf_pos = ECDF(bg_position)
-        ecdf_nar = ECDF(bg_narrow)
+        # ecdf_pos = ECDF(bg_position)
+        # ecdf_nar = ECDF(bg_narrow)
 
         # Genomic array to store the p-values for every chromosome:position object
         ga_pval = HTSeq.GenomicArray("auto", typecode='O', stranded=False)
 
         # Ratio to be used in scaling the nuclease count
-        scale_factor = total_control_count/float(total_nuclease_count)
+        # scale_factor = total_control_count/float(total_nuclease_count)
 
         for idx, fields in enumerate(output_list):
-            position_p_val = 1 - ecdf_pos(fields[2]*scale_factor)
-            narrow_p_val = 1 - ecdf_nar(fields[4]*scale_factor)
+            # position_p_val = 1 - ecdf_pos(fields[2]*scale_factor) ## not used
+            # narrow_p_val = 1 - ecdf_nar(fields[4]*scale_factor)
 
-            control_position_p_val = 1 - ecdf_pos(fields[3])
-            control_narrow_p_val = 1 - ecdf_nar(fields[5])
+            # control_position_p_val = 1 - ecdf_pos(fields[3])
+            # control_narrow_p_val = 1 - ecdf_nar(fields[5])
+            position_p_val = 1 
+            narrow_p_val = 1 
+
+            control_position_p_val = 1 
+            control_narrow_p_val = 1 
 
             #if narrow_p_val < 0.01 or position_p_val < 0.01:
             ## read threshold is here: Yichao, read_count_cutoff
